@@ -2,5 +2,5 @@ from django.conf.urls import patterns, url
 
 
 urlpatterns = patterns(
-    'extended_validation.views',
+    'validation_extended.views',
     url(r'^validate/?$', 'remote_validation'))
